@@ -29,45 +29,46 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
-import javax.faces.context.FacesContext;
-import javax.faces.context.ResponseStream;
-import javax.faces.context.ResponseWriter;
-import javax.faces.render.ClientBehaviorRenderer;
-import javax.faces.render.RenderKit;
-import javax.faces.render.Renderer;
-import javax.faces.render.ResponseStateManager;
+import jakarta.faces.context.FacesContext;
+import jakarta.faces.context.ResponseStream;
+import jakarta.faces.context.ResponseWriter;
+import jakarta.faces.render.ClientBehaviorRenderer;
+import jakarta.faces.render.RenderKit;
+import jakarta.faces.render.Renderer;
+import jakarta.faces.render.RendererWrapper;
+import jakarta.faces.render.ResponseStateManager;
 
 import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFRenderKit;
-import org.apache.myfaces.shared.config.MyfacesConfig;
-import org.apache.myfaces.shared.renderkit.ContentTypeUtils;
-import org.apache.myfaces.shared.renderkit.html.HtmlRendererUtils;
-import org.apache.myfaces.shared.renderkit.html.HtmlResponseWriterImpl;
+import org.apache.myfaces.config.webparameters.MyfacesConfig;
+import org.apache.myfaces.renderkit.LazyRenderKit;
+import org.apache.myfaces.renderkit.ContentTypeUtils;
+import org.apache.myfaces.core.api.shared.lang.Assert;
+import org.apache.myfaces.util.lang.ClassUtils;
 
 /**
- * @author Manfred Geiler (latest modification by $Author: lu4242 $)
- * @version $Revision: 1634746 $ $Date: 2014-10-27 23:58:18 +0000 (Mon, 27 Oct 2014) $
+ * @author Manfred Geiler (latest modification by $Author$)
+ * @version $Revision$ $Date$
  */
 @JSFRenderKit(renderKitId = "HTML_BASIC")
-public class HtmlRenderKitImpl extends RenderKit
+public class HtmlRenderKitImpl extends RenderKit implements LazyRenderKit
 {
-    //private static final Log log = LogFactory.getLog(HtmlRenderKitImpl.class);
     private static final Logger log = Logger.getLogger(HtmlRenderKitImpl.class.getName());
 
     // ~ Instance fields ----------------------------------------------------------------------------
 
     private Map<String, Map<String, Renderer>> _renderers;
     private ResponseStateManager _responseStateManager;
-    //private Map<String,Set<String>> _families;
     private Map<String, ClientBehaviorRenderer> _clientBehaviorRenderers;
-
+    private MyfacesConfig myfacesConfig;
+    
     // ~ Constructors -------------------------------------------------------------------------------
 
     public HtmlRenderKitImpl()
     {
-        _renderers = new ConcurrentHashMap<String, Map<String, Renderer>>(64, 0.75f, 1);
+        _renderers = new ConcurrentHashMap<>(64, 0.75f, 1);
         _responseStateManager = new HtmlResponseStateManager();
-        //_families = new HashMap<String, Set<String> >();
-        _clientBehaviorRenderers = new HashMap<String, ClientBehaviorRenderer>();
+        _clientBehaviorRenderers = new HashMap<>();
+        myfacesConfig = MyfacesConfig.getCurrentInstance();
     }
 
     // ~ Methods ------------------------------------------------------------------------------------
@@ -75,14 +76,8 @@ public class HtmlRenderKitImpl extends RenderKit
     @Override
     public void addClientBehaviorRenderer(String type, ClientBehaviorRenderer renderer)
     {
-        if (type == null)
-        {
-            throw new NullPointerException("client behavior renderer type must not be null");
-        }
-        if ( renderer == null)
-        {
-            throw new NullPointerException("client behavior renderer must not be null");
-        }
+        Assert.notNull(type, "type");
+        Assert.notNull(renderer, "renderer");
         
         _clientBehaviorRenderers.put(type, renderer);
     }
@@ -90,10 +85,7 @@ public class HtmlRenderKitImpl extends RenderKit
     @Override
     public ClientBehaviorRenderer getClientBehaviorRenderer(String type)
     {
-        if (type == null)
-        {
-            throw new NullPointerException("client behavior renderer type must not be null");
-        }
+        Assert.notNull(type, "type");
         
         return _clientBehaviorRenderers.get(type);
     }
@@ -107,14 +99,9 @@ public class HtmlRenderKitImpl extends RenderKit
     @Override
     public Renderer getRenderer(String componentFamily, String rendererType)
     {
-        if (componentFamily == null)
-        {
-            throw new NullPointerException("component family must not be null.");
-        }
-        if (rendererType == null)
-        {
-            throw new NullPointerException("renderer type must not be null.");
-        }
+        Assert.notNull(componentFamily, "componentFamily");
+        Assert.notNull(rendererType, "rendererType");
+        
         Map <String,Renderer> familyRendererMap = _renderers.get(componentFamily); 
         Renderer renderer = null;
         if (familyRendererMap != null)
@@ -123,7 +110,12 @@ public class HtmlRenderKitImpl extends RenderKit
         }
         if (renderer == null)
         {
-            log.warning("Unsupported component-family/renderer-type: " + componentFamily + "/" + rendererType);
+            log.warning("Unsupported component-family/renderer-type: " + componentFamily + '/' + rendererType);
+        }
+        if (renderer instanceof LazyRendererWrapper)
+        {
+            renderer = ((LazyRendererWrapper)renderer).getWrapped();
+            familyRendererMap.put(rendererType, renderer);
         }
         return renderer;
     }
@@ -131,22 +123,10 @@ public class HtmlRenderKitImpl extends RenderKit
     @Override
     public void addRenderer(String componentFamily, String rendererType, Renderer renderer)
     {
-        if (componentFamily == null)
-        {
-            log.severe("addRenderer: componentFamily = null is not allowed");
-            throw new NullPointerException("component family must not be null.");
-        }
-        if (rendererType == null)
-        {
-            log.severe("addRenderer: rendererType = null is not allowed");
-            throw new NullPointerException("renderer type must not be null.");
-        }
-        if (renderer == null)
-        {
-            log.severe("addRenderer: renderer = null is not allowed");
-            throw new NullPointerException("renderer must not be null.");
-        }
-        
+        Assert.notNull(componentFamily, "componentFamily");
+        Assert.notNull(rendererType, "rendererType");
+        Assert.notNull(renderer, "renderer");
+
         _put(componentFamily, rendererType, renderer);
 
         if (log.isLoggable(Level.FINEST))
@@ -156,6 +136,22 @@ public class HtmlRenderKitImpl extends RenderKit
         }
     }
     
+    @Override
+    public void addRenderer(String componentFamily, String rendererType, String rendererClass)
+    {
+        Assert.notNull(componentFamily, "componentFamily");
+        Assert.notNull(rendererType, "rendererType");
+        Assert.notNull(rendererClass, "rendererClass");
+
+        _put(componentFamily, rendererType, new LazyRendererWrapper(rendererClass));
+
+        if (log.isLoggable(Level.FINEST))
+        {
+            log.finest("add Renderer family = " + componentFamily + " rendererType = " + rendererType
+                    + " renderer class = " + rendererClass);
+        }
+    }
+
     /**
      * Put the renderer on the double map
      * 
@@ -168,7 +164,7 @@ public class HtmlRenderKitImpl extends RenderKit
         Map <String,Renderer> familyRendererMap = _renderers.get(componentFamily);
         if (familyRendererMap == null)
         {
-            familyRendererMap = new ConcurrentHashMap<String, Renderer>(8, 0.75f, 1);
+            familyRendererMap = new ConcurrentHashMap<>(8, 0.75f, 1);
             _renderers.put(componentFamily, familyRendererMap);
         }
         else
@@ -193,7 +189,7 @@ public class HtmlRenderKitImpl extends RenderKit
     }
     
     /**
-     * @since JSF 2.0
+     * @since Faces 2.0
      */
     @Override
     public Iterator<String> getComponentFamilies()
@@ -203,7 +199,7 @@ public class HtmlRenderKitImpl extends RenderKit
     }
     
     /**
-     * @since JSF 2.0
+     * @since Faces 2.0
      */
     @Override
     public Iterator<String> getRendererTypes(String componentFamily)
@@ -214,25 +210,15 @@ public class HtmlRenderKitImpl extends RenderKit
         {
             return map.keySet().iterator();
         }
-        /*
-        Set<String> rendererTypes = _families.get(componentFamily);
-        if(rendererTypes != null)
-        {
-            return rendererTypes.iterator();
-        }*/
+
         //If the specified componentFamily is not known to this RenderKit implementation, return an empty Iterator
-        return Collections.<String>emptySet().iterator();
-        
-
-
+        return Collections.emptyIterator();
     }
 
     @Override
     public ResponseWriter createResponseWriter(Writer writer, String contentTypeListString, String characterEncoding)
     {
         FacesContext facesContext = FacesContext.getCurrentInstance();
-        MyfacesConfig myfacesConfig = MyfacesConfig.getCurrentInstance(
-                facesContext.getExternalContext());
         String selectedContentType = null;
         String writerContentType = null;
         boolean isAjaxRequest = facesContext.getPartialViewContext().isAjaxRequest();
@@ -331,23 +317,30 @@ public class HtmlRenderKitImpl extends RenderKit
         {
             // If HTTP Accept header has application/xml or text/xml, that does not means the writer
             // content type mode should be set to application/xhtml+xml.
-            writerContentType = selectedContentType.indexOf(ContentTypeUtils.XHTML_CONTENT_TYPE) != -1 ?
+            writerContentType = selectedContentType.contains(ContentTypeUtils.XHTML_CONTENT_TYPE) ?
                     ContentTypeUtils.XHTML_CONTENT_TYPE : ContentTypeUtils.HTML_CONTENT_TYPE;
         }
         else
         {
-            writerContentType = HtmlRendererUtils.isXHTMLContentType(selectedContentType) ? 
+            writerContentType = ContentTypeUtils.isXHTMLContentType(selectedContentType) ? 
                     ContentTypeUtils.XHTML_CONTENT_TYPE : ContentTypeUtils.HTML_CONTENT_TYPE;
         }
         
         if (characterEncoding == null)
         {
-            characterEncoding = HtmlRendererUtils.DEFAULT_CHAR_ENCODING;
+            characterEncoding = ContentTypeUtils.DEFAULT_CHAR_ENCODING;
         }
 
-        return new HtmlResponseWriterImpl(writer, selectedContentType, characterEncoding, 
-                myfacesConfig.isWrapScriptContentWithXmlCommentTag(),
-                        writerContentType);
+        if (myfacesConfig.isEarlyFlushEnabled())
+        {
+            return new EarlyFlushHtmlResponseWriterImpl(writer, selectedContentType, characterEncoding, 
+                myfacesConfig.isWrapScriptContentWithXmlCommentTag(), writerContentType);
+        }
+        else
+        {
+            return new HtmlResponseWriterImpl(writer, selectedContentType, characterEncoding, 
+                myfacesConfig.isWrapScriptContentWithXmlCommentTag(), writerContentType);
+        }
     }
 
     @Override
@@ -355,14 +348,6 @@ public class HtmlRenderKitImpl extends RenderKit
     {
         return new MyFacesResponseStream(outputStream);
     }
-    
-    private void checkNull(Object value, String valueLabel)
-    {
-        if (value == null)
-        {
-            throw new NullPointerException(valueLabel + " is null");
-        }
-    }
 
     private static class MyFacesResponseStream extends ResponseStream
     {
@@ -380,13 +365,13 @@ public class HtmlRenderKitImpl extends RenderKit
         }
 
         @Override
-        public void write(byte b[]) throws IOException
+        public void write(byte[] b) throws IOException
         {
             output.write(b);
         }
 
         @Override
-        public void write(byte b[], int off, int len) throws IOException
+        public void write(byte[] b, int off, int len) throws IOException
         {
             output.write(b, off, len);
         }
@@ -403,4 +388,26 @@ public class HtmlRenderKitImpl extends RenderKit
             output.close();
         }
     }
+    
+    private static class LazyRendererWrapper extends RendererWrapper
+    {
+        private String rendererClass;
+        private Renderer delegate;
+        
+        public LazyRendererWrapper(String rendererClass)
+        {
+            this.rendererClass = rendererClass;
+        }
+
+        @Override
+        public Renderer getWrapped()
+        {
+            if (delegate == null)
+            {
+                delegate = (Renderer) ClassUtils.newInstance(
+                    ClassUtils.simpleClassForName(rendererClass));
+            }
+            return delegate;
+        }
+    }
 }
